@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2011 by Ilya Kotov                                      *
- *   forkotov02@hotmail.ru                                                 *
+ *   Copyright (C) 2011-2016 by Ilya Kotov                                 *
+ *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -112,12 +112,12 @@ bool DecoderFFap::initialize()
     return true;
 }
 
-qint64 DecoderFFap::totalTime()
+qint64 DecoderFFap::totalTime() const
 {
     return m_ffap_decoder->duration * 1000;
 }
 
-int DecoderFFap::bitrate()
+int DecoderFFap::bitrate() const
 {
     return m_ffap_decoder->bitrate;
 }
@@ -127,7 +127,7 @@ void DecoderFFap::seek(qint64 time)
     ffap_seek(m_ffap_decoder, time / 1000.0);
 }
 
-qint64 DecoderFFap::read(char *data, qint64 size)
+qint64 DecoderFFap::read(unsigned char *data, qint64 size)
 {
     return ffap_read(m_ffap_decoder, data, size);
 }
