@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2011-2012 by Ilya Kotov                                 *
- *   forkotov02@hotmail.ru                                                 *
+ *   Copyright (C) 2011-2019 by Ilya Kotov                                 *
+ *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,6 +23,9 @@
 #include <QRegExp>
 #include <taglib/apefile.h>
 #include <taglib/apetag.h>
+#if (TAGLIB_MAJOR_VERSION > 1) || ((TAGLIB_MAJOR_VERSION == 1) && (TAGLIB_MINOR_VERSION >= 8))
+#include <taglib/tfilestream.h>
+#endif
 #include "cueparser.h"
 #include "decoder_ffap.h"
 #include "decoder_ffapcue.h"
@@ -37,6 +40,12 @@ DecoderFFapCUE::DecoderFFapCUE(const QString &url)
     m_track = 0;
     m_buf = 0;
     m_input = 0;
+    m_length = 0;
+    m_offset = 0;
+    m_totalBytes = 0;
+    m_buf_size = 0;
+    m_sz = 0;
+    length_in_bytes = 0;
 }
 
 DecoderFFapCUE::~DecoderFFapCUE()
@@ -67,7 +76,13 @@ bool DecoderFFapCUE::initialize()
     p.remove(QRegExp("#\\d+$"));
 
 
-    TagLib::APE::File file(p.toLocal8Bit().constData());
+#if (TAGLIB_MAJOR_VERSION > 1) || ((TAGLIB_MAJOR_VERSION == 1) && (TAGLIB_MINOR_VERSION >= 8))
+    TagLib::FileStream stream(QStringToFileName(p), true);
+    TagLib::APE::File file(&stream);
+#else
+    TagLib::APE::File file(QStringToFileName(p));
+#endif
+
     TagLib::APE::Tag *tag = file.APETag();
 
     if (tag && tag->itemListMap().contains("CUESHEET"))
@@ -96,7 +111,7 @@ bool DecoderFFapCUE::initialize()
     QMap<Qmmp::MetaData, QString> metaData = m_parser->info(m_track)->metaData();
     addMetaData(metaData); //send metadata
 
-    m_length = m_parser->length(m_track);
+    m_length = m_parser->duration(m_track);
     m_offset = m_parser->offset(m_track);
 
     m_decoder = new DecoderFFap(p, m_input);
@@ -123,7 +138,7 @@ bool DecoderFFapCUE::initialize()
     return true;
 }
 
-qint64 DecoderFFapCUE::totalTime()
+qint64 DecoderFFapCUE::totalTime() const
 {
     return m_decoder ? m_length : 0;
 }
@@ -136,7 +151,7 @@ void DecoderFFapCUE::seek(qint64 pos)
             audioParameters().sampleSize() * pos/1000;
 }
 
-qint64 DecoderFFapCUE::read(char *data, qint64 size)
+qint64 DecoderFFapCUE::read(unsigned char *data, qint64 size)
 {
     if(length_in_bytes - m_totalBytes < m_sz) //end of cue track
         return 0;
@@ -180,12 +195,12 @@ qint64 DecoderFFapCUE::read(char *data, qint64 size)
     return len2;
 }
 
-int DecoderFFapCUE::bitrate()
+int DecoderFFapCUE::bitrate() const
 {
     return m_decoder->bitrate();
 }
 
-const QString DecoderFFapCUE::nextURL()
+const QString DecoderFFapCUE::nextURL() const
 {
     if(m_track +1 <= m_parser->count())
         return m_parser->trackURL(m_track + 1);
@@ -198,7 +213,7 @@ void DecoderFFapCUE::next()
     if(m_track +1 <= m_parser->count())
     {
         m_track++;
-        m_length = m_parser->length(m_track);
+        m_length = m_parser->duration(m_track);
         m_offset = m_parser->offset(m_track);
         length_in_bytes = audioParameters().sampleRate() *
                 audioParameters().channels() *
